diff --git a/ChangeLog b/ChangeLog
index 4f011cbe2bd7e1e6604c5560535da2f18e328fa9..04e421382832e4058cb57f78c4bd2ac2241c26a2 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -129,6 +129,9 @@ CVS code -
 	- Since proto.h includes nano.h, and nano.h includes config.h
 	  first, include proto.h first and remove redundant includes of
 	  config.h in all non-header source files. (DLR)
+	- Refer to the Enter key instead of the Return key for
+	  consistency.  Changes to load_history() and rcfile_error().
+	  (DLR)
 - browser.c:
   do_browser()
 	- When setting the width of each file, use the "?" operator
diff --git a/src/files.c b/src/files.c
index 12fde7bf7db4b9929a307f1556ef8a1bff00551c..e61a3122a33c875f32120dcd14a3241a445d7982 100644
--- a/src/files.c
+++ b/src/files.c
@@ -2335,7 +2335,7 @@ void load_history(void)
 		rcfile_error(N_("Error reading %s: %s"), nanohist,
 			strerror(errno));
 		fprintf(stderr,
-			_("\nPress Return to continue starting nano\n"));
+			_("\nPress Enter to continue starting nano\n"));
 		while (getchar() != '\n')
 		    ;
 	    }
diff --git a/src/text.c b/src/text.c
index b34ffaaa01e8baf40248f6d00a4f56337a20c831..3461e66e80fc68f7927d1380214e3319373a3997 100644
--- a/src/text.c
+++ b/src/text.c
@@ -192,7 +192,7 @@ void do_tab(void)
 #endif
 }
 
-/* Someone hits Enter/Return *gasp!* */
+/* Someone hits Enter *gasp!* */
 void do_enter(void)
 {
     filestruct *newnode = make_new_node(openfile->current);
diff --git a/src/winio.c b/src/winio.c
index bc75a7bc841d8b7ab743a90faf869ddbedba38cf..e7b4b92df37baf0eb3c1ac773870d9788e020432 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -2285,9 +2285,9 @@ void edit_draw(const filestruct *fileptr, const char *converted, int
 	    if (tmpcolor->bright)
 		wattron(edit, A_BOLD);
 	    wattron(edit, COLOR_PAIR(tmpcolor->pairnum));
-	    /* Two notes about regexec().  Return value 0 means there is
-	     * a match.  Also, rm_eo is the first non-matching character
-	     * after the match. */
+	    /* Two notes about regexec().  A return value of zero means
+	     * that there is a match.  Also, rm_eo is the first
+	     * non-matching character after the match. */
 
 	    /* First case, tmpcolor is a single-line expression. */
 	    if (tmpcolor->end == NULL) {
diff --git a/src/rcfile.c b/src/rcfile.c
index e55eac6f07a2a27815180e97f1d1702281beaa39..fd58867a05c7dcc7117e207714782d2c2326de2c 100644
--- a/src/rcfile.c
+++ b/src/rcfile.c
@@ -107,7 +107,7 @@ static colortype *endcolor = NULL;
 #endif
 
 /* We have an error in some part of the rcfile.  Put it on stderr and
  * make the user hit Return to continue starting up nano. */
 void rcfile_error(const char *msg, ...)
 {
     va_list ap;
@@ -735,7 +735,7 @@ void parse_rcfile(FILE *rcstream)
 
     if (errors) {
 	errors = FALSE;
-	fprintf(stderr, _("\nPress Return to continue starting nano\n"));
+	fprintf(stderr, _("\nPress Enter to continue starting nano\n"));
 	while (getchar() != '\n')
 	    ;
     }
@@ -107,7 +107,7 @@ static colortype *endcolor = NULL;
 
 /* We have an error in some part of the rcfile.  Put it on stderr and
- * make the user hit Return to continue starting up nano. */
+ * make the user hit Enter to continue starting up nano. */
 void rcfile_error(const char *msg, ...)
 {